#if FNODATDEF > 0
      integer bufsize
      parameter (bufsize=BUFSIZE)
      type(buffer):: buf(bufsize)
#endif
